@@ -1,8 +1,9 @@
 library(diveMove)
 
-(sealX <- readTDR(system.file(file.path("data", "dives.csv"),
-                              package="diveMove"), concurrentCols=4:6,
-                  sep=";", na.strings="", as.is=TRUE))
+zz <- gzfile(system.file(file.path("data", "dives.csv.gz"),
+                         package="diveMove"), open="r")
+(sealX <- readTDR(zz, concurrentCols=4:6, sep=";",
+                  na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, zoc.method="offset", offset=3))
 tdrstats <- diveStats(dcalib)
 head(tdrstats)
@@ -10,9 +11,9 @@ head(stamps <- stampDive(dcalib))
 (att <- timeBudget(dcalib, FALSE))
 (att <- timeBudget(dcalib, TRUE))
 
-(sealX <- readTDR(system.file(file.path("data", "dives.csv"),
-                              package="diveMove"),
-                  speed=TRUE, concurrentCols=4:6,
+zz <- gzfile(system.file(file.path("data", "dives.csv.gz"),
+                         package="diveMove"), open="r")
+(sealX <- readTDR(zz, speed=TRUE, concurrentCols=4:6,
                   sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, zoc.method="offset", offset=3))
 (vcalib <- calibrateSpeed(dcalib, z=1))
